@@ -10,9 +10,9 @@ use strict;
 package Authen::PluggableCaptcha::Challenge::TypeString;
 
 use vars qw(@ISA $VERSION);
-$VERSION= '0.01';
+$VERSION= '0.02';
 
-use Authen::PluggableCaptcha::Challenge;
+use Authen::PluggableCaptcha::Challenge ();
 our @ISA= qw( Authen::PluggableCaptcha::Challenge );
 
 ######################################################
@@ -33,23 +33,27 @@ sub new {
 	my  ( $proto , %kw_args )= @_;
 	my  $class= ref($proto) || $proto;
 	my  $self= bless ( {} , $class );
-		$self->{'keygenerator_instance'}= $kw_args{'keygenerator_instance'} || die "must supply 'keygenerator_instance'";
-		$self->{'instructions'}= "Please type the text you see";
-		$self->{'user_prompt'}= 
+	
+		die "must supply 'keymanager_instance'" unless $kw_args{'keymanager_instance'};
+		
+		$self->_keymanager( $kw_args{'keymanager_instance'} );
+		$self->_instructions("Please type the text you see");
+		$self->_user_prompt(
 			substr(
 				md5_hex( 
 					sprintf(
 						"%s|%s|%s|%s" , 
-							$self->{'keygenerator_instance'}->{'site_secret'},
-							$self->{'keygenerator_instance'}->{'publickey'},
-							$self->{'keygenerator_instance'}->{'publickey'},
-							$self->{'keygenerator_instance'}->{'time_start'}
+							$self->keymanager->site_secret,
+							$self->keymanager->publickey,
+							$self->keymanager->publickey,
+							$self->keymanager->time_start
 					)
 				),
 				0,
 				6
-			);
-	$self->{'correct_response'}= $self->{'user_prompt'};
+			)
+		);
+	$self->_correct_response( $self->user_prompt );
 	return $self;
 }
 
@@ -58,7 +62,7 @@ sub validate {
 	if ( ! defined $kw_args{'user_response'} || !$kw_args{'user_response'} ) {
 		die "validate must be called with a 'user_response' argument";
 	}
-	if ( lc($kw_args{'user_response'}) eq lc($self->{'correct_response'}) ) {
+	if ( lc($kw_args{'user_response'}) eq lc($self->correct_response) ) {
 		return 1;		
 	}
 	return 0;
